/*######################################################################
#                                                                      #
#          Deutsche Boerse AG, Frankfurt, Germany                      #
#          Xontro QSAM Release 01                                      #
#                                                                      #
########################################################################*/
/*****************************************************************************
*
*  DESCRIPTION: bclayouts_qsam.h
*               ids, layouts and constants for Xontro QSAM
*
*  MODIFICATION HISTORY:
*
*  DATE        PROG.
*  DD-MMM-YYYY INIT.   MODIFICATION DESCRIPTION
*  ----------- ------- ------------------------------------------------
*  08-JUL-2019 IT814   Xontro QSAM release 01
*****************************************************************************/

#ifndef _BC_BCLAYOUTS_QSAM_H_
#define _BC_BCLAYOUTS_QSAM_H_

/* Constants for application logic */

#define MAX_NO_PRC_DEFAULT     2        /* default blocksize for price request   */


/* request ids */

#define BC_LOGIN_RID                                    "004"
#define BC_LOGIN_QUOTE_BYPASS_RID                       "005"
#define BC_LOGOUT_RID                                   "007"
#define BC_ENTER_ORDER_FM_RID                           "102"
#define BC_MODIFY_ORDER_FM_RID                          "103"
#define BC_DELETE_ORDER_FM_RID                          "104"
#define BC_RET_ORDER_UPDATE_RID                         "105"
#define BC_RET_ORDER_EXECUTION_UPDATE_RID               "106"
#define BC_RET_SYSTEM_STATUS_NEWS_RID                   "107"
#define BC_RET_BROKER_TRADE_UPDATE_RID                  "108"
#define BC_RET_OWN_TRADE_UPDATE_RID                     "109"
#define BC_RET_PRIVATE_STATUS_NEWS_RID                  "110"
#define BC_ENTER_BLOCK_PRICE_RID                        "114"
#define BC_ENTER_QUOTE_RID                              "116"
#define BC_ENTER_ORDER_SKM_RID                          "117"
#define BC_MODIFY_ORDER_SKM_RID                         "118"
#define BC_DELETE_ORDER_SKM_RID                         "119"
#define BC_RESET_PRICE_RID                              "120"
#define BC_RESET_PRICE_INFO_RID                         "121"
#define BC_DEACTIVATE_PRICING_BLOCK_RID                 "128"
#define BC_REACTIVATE_PRICING_BLOCK_RID                 "129"
#define BC_START_PRICING_RID                            "130"
#define BC_ENTER_PRICE_RID                              "131"
#define BC_CANCEL_PRICING_RID                           "132"
#define BC_ADD_POSITION_RID                             "133"
#define BC_MODIFY_EXECUTION_RID                         "134"
#define BC_FINISH_PRICING_RID                           "135"
#define BC_DEACTIVATE_PRICING_RID                       "136"
#define BC_REACTIVATE_PRICING_RID                       "137"
#define BC_ENTER_SP_RIGHT_RID                           "138"
#define BC_ENTER_PRICE_PLUS_RID                         "139"
#define BC_ENTER_BROKER_TRADE_RID                       "140"
#define BC_CANCEL_TRADE_RID                             "141"
#define BC_DELETE_BROKER_TRADE_RID                      "142"
#define BC_MATCH_BROKER_TRADE_RID                       "143"
#define BC_MATCH_ALL_BROKER_TRADES_RID                  "144"
#define BC_ENTER_SINGLE_TRADE_RID                       "145"
#define BC_ENTER_EXCHANGE_TRADE_RID                     "180"
#define BC_ENTER_EXCHANGE_TRADE_REF_RID                 "181"
#define BC_CHANGE_PASSWORD_RID                          "199"
#define BC_ENTER_MASS_QUOTE_RID                         "216"


/* broadcast stream types */

#define BC_PUBLIC_SYSTEM_STATUS_STREAM_TYPE             "01"
#define BC_PRIVATE_STATUS_STREAM_TYPE                   "02"
#define BC_PRIVATE_ORDER_UPDATE_STREAM_TYPE             "11"
#define BC_PRIVATE_ORDER_EXECUTION_UPDATE_STREAM_TYPE   "12"
#define BC_PRIVATE_BROKER_TRADE_UPDATE_STREAM_TYPE      "38"
#define BC_PRIVATE_OWN_TRADE_UPDATE_STREAM_TYPE         "39"

/* retransmission stream types */

#define BC_RET_SYSTEM_STATUS_STREAM_TYPE                "51"
#define BC_RET_PRIVATE_STATUS_STREAM_TYPE               "52"
#define BC_RET_ORDER_UPDATE_STREAM_TYPE                 "53"
#define BC_RET_ORDER_EXECUTION_UPDATE_STREAM_TYPE       "54"
#define BC_RET_BROKER_TRADE_UPDATE_STREAM_TYPE          "55"
#define BC_RET_OWN_TRADE_UPDATE_STREAM_TYPE             "56"

/* inquire stream types */

#define BC_INQUIRE_ORDERS_STREAM_TYPE                   "60"
#define BC_INQUIRE_SPECIAL_ORDERS_STREAM_TYPE           "61"
#define BC_INQUIRE_BROKER_TRADES_STREAM_TYPE            "62"
#define BC_INQUIRE_BROKER_DIARY_STREAM_TYPE             "63"
#define BC_INQUIRE_SP_RIGHTS_STREAM_TYPE                "64"
#define BC_INQUIRE_SKONTRO_DATA_STREAM_TYPE             "65"
#define BC_INQUIRE_SKONTRO_ISIN_STREAM_TYPE             "66"


/* subtypes */

#define BCBE_ENTER_ORDER                                "001"
#define BCFE_ENTER_ORDER                                "002"
#define BCBE_MODIFY_ORDER                               "003"
#define BCFE_MODIFY_ORDER                               "004"
#define BCBE_DELETE_ORDER                               "005"
#define BCFE_DELETE_ORDER                               "006"
#define BCBE_MODIFY_ORDER_N                             "007"
#define BCBE_DELETE_ORDER_N                             "008"
#define BCBE_EXECUTION_SKM                              "011"
#define BCBE_EXECUTION_SKM_TO_FM                        "012"
#define BCBE_BUS_START                                  "014"
#define BCBE_BUS_END                                    "015"
#define BCBE_ENDOFDAY_START                             "016"
#define BCFE_ENTER_ORDER_DIR                            "021"
#define BCFE_MODIFY_ORDER_DIR                           "022"
#define BCFE_DELETE_ORDER_DIR                           "023"
#define BCBE_ENTER_ORDER_FM                             "025"
#define BCBE_ENTER_PRICE_MAN                            "030"
#define BCBE_ENTER_PRICE_MODIFICATION_MAN               "031"
#define BCFE_ENTER_BLOCK_PRICE                          "032"
#define BCBE_ENTER_SP_RIGHT                             "033"
#define BCBE_BT                                         "034"
#define BCBE_BT_END                                     "035"
#define BCBE_ENTER_QUOTE                                "041"
#define BCFE_ENTER_QUOTE                                "042"
#define BCBE_ENTER_PRICE                                "044"
#define BCBE_DEACTIVATE_QUOTE                           "046"
#define BCFE_DEACTIVATE_QUOTE                           "048"
#define BCBE_DEACTIVATE_PRICING                         "050"
#define BCBE_REACTIVATE_PRICING                         "051"
#define BCBE_DEACTIVATE_ANY_PRICING                     "052"
#define BCBE_REACTIVATE_ANY_PRICING                     "053"
#define BCBE_STOP_TRADE                                 "054"
#define BCBE_START_TRADE                                "055"
#define BCBE_START_QUOTE                                "056"
#define BCBE_STOP_QUOTE                                 "057"
#define BCBE_EXCHANGE_QUOTE_VOLUME_INFO                 "058"
#define BCBE_ORDERS_END                                 "061"
#define BCBE_SPECIAL_END                                "063"
#define BCBE_ORDER                                      "065"
#define BCBE_ORDER_DELETED_N                            "066"
#define BCBE_DIARY                                      "067"
#define BCBE_DIARY_END                                  "068"
#define BCFE_DEACTIVATE_PRICING                         "070"
#define BCFE_REACTIVATE_PRICING                         "071"
#define BCFE_ENTER_SP_RIGHT                             "072"
#define BCFE_DEACTIVATE_PRICING_BLOCK                   "073"
#define BCFE_REACTIVATE_PRICING_BLOCK                   "074"
#define BCBE_ENTER_PRICE_TAB                            "080"
#define BCBE_ENTER_PRICE_MODIFICATION_TAB               "081"
#define BCBE_ENTER_BTRADE_2                             "091"
#define BCFE_ENTER_BTRADE_2                             "092"
#define BCBE_BTRADE_2                                   "093"
#define BCFE_REJ_ENTER_ORDER                            "101"
#define BCFE_REJ_MODIFY_ORDER                           "102"
#define BCFE_REJ_DELETE_ORDER                           "103"
#define BCFE_ENTER_ORDER_SKM                            "104"
#define BCFE_MODIFY_ORDER_SKM                           "105"
#define BCFE_DELETE_ORDER_SKM                           "106"
#define BCBE_ENTER_TEMP_BTRADE                          "111"
#define BCBE_MODIFY_TEMP_BTRADE                         "112"
#define BCBE_DELETE_TEMP_BTRADE                         "113"
#define BCBE_ENTER_BTRADE                               "114"
#define BCBE_DELETE_BTRADE                              "115"
#define BCBE_CANCEL_BTRADE                              "116"
#define BCBE_MODIFY_BTRADE                              "117"
#define BCBE_MATCH_BTRADE                               "118"
#define BCFE_DELETE_BTRADE                              "119"
#define BCFE_CANCEL_BTRADE                              "120"
#define BCFE_ENTER_BTRADE                               "122"
#define BCFE_MATCH_BTRADE                               "123"
#define BCBE_TRADE                                      "124"
#define BCBE_MODIFY_HUM                                 "125"
#define BCFE_MODIFY_HUM                                 "126"
#define BCBE_BROKER_DIARY                               "127"
#define BCBE_PEND_ENTER_ORDER                           "130"
#define BCBE_REJ_ENTER_ORDER                            "131"
#define BCBE_PEND_MODIFY_ORDER                          "132"
#define BCBE_CONFIRM_MODIFY_ORDER                       "133"
#define BCBE_PEND_DELETE_ORDER                          "134"
#define BCBE_CONFIRM_DELETE_ORDER                       "135"
#define BCBE_MODIFY_SBSL                                "136"
#define BCBE_SKONTRO_END                                "150"
#define BCBE_SKONTRO_ISIN                               "151"
#define BCBE_SKONTRO_DATA                               "152"
#define BCFE_RESET_ORDER_SKM                            "160"
#define BCFE_RESET_ORDER_SKM_END                        "161"
#define BCFE_RESET_ORDER_FM                             "162"
#define BCFE_RESET_ORDER_FM_END                         "163"
#define BCFE_RESET_PRICE                                "164"
#define BCBE_BTRADE                                     "165"
#define BCBE_BTRADES_END                                "166"
#define BCBE_UNLOCK_ORDERS                              "170"
#define BCBE_FINISH_PRICING                             "171"
#define BCBE_END_EXECUTION                              "172"
#define BCBE_LOCK_ORDERS                                "173"
#define BCFE_LOCK_ORDERS                                "174"
#define BCFE_ENTER_PRICE                                "175"
#define BCFE_FINISH_PRICING                             "176"
#define BCFE_UNLOCK_ORDERS                              "177"
#define BCFE_MODIFY_EXECUTION                           "178"
#define BCFE_ADD_POSITION                               "179"
#define BCFE_ENTER_PRICE_PLUS                           "180"
#define BCBE_MODIFY_EXECUTION                           "181"
#define BCBE_ADD_POSITION                               "182"
#define BCBE_BYPASS_QUOTE_VOLUME_INFO                   "185"
#define BCBE_LOST_MESSAGE                               "198"
#define BCBE_NOTIFY_PW_EXPIRATION_DATE                  "199"
#define BCBE_NO_DATA                                    "999"


/* execConfTyp valid values */

#define BC_FV_EXEC_CONF_DISP            "002"
#define BC_FV_EXEC_CONF_FINAL           "005"

/* errFieldRef valid values for BCBE_STOP_QUOTE broadcasts*/

#define BC_ON_REQUEST                   "001"
#define BC_VOLUME_OVERFLOW              "002"
#define BC_EXCHANGE_VOLUME_OVERFLOW     "003"

/* special values */

#define BC_INIT_CONFIRM_TIM             "00000000"
#define BC_DO_NOT_CHECK_CONFIRM_TIM     "99999997"
#define BC_DO_NOT_CONFIRM               "99999999"
#define BC_DO_NOT_CHECK_TICKET          "999999999"


/* error field references */

#define BC_ERR_FIELD_UNDEFINED                          "000"   /* undefined                */
#define BC_ERR_FIELD_ACCT_TYP_COD_XONTRO                "001"   /* acctTypCodXontro         */
#define BC_ERR_FIELD_NET_TYP_COD_XONTRO                 "002"   /* netTypCodXontro          */
#define BC_ERR_FIELD_BC_PWD                             "003"   /* bcPwd                    */
#define BC_ERR_FIELD_BKR_NO                             "004"   /* bkrNo                    */
#define BC_ERR_FIELD_BKR_USER_NO                        "005"   /* bkrUserNo                */
#define BC_ERR_FIELD_BUY_COD                            "006"   /* buyCod                   */
#define BC_ERR_FIELD_CTPY_NO                            "007"   /* ctpyNo                   */
#define BC_ERR_FIELD_EXCHANGE_ID                        "008"   /* exchangeId               */
#define BC_ERR_FIELD_IN_SEQ_NO_REF                      "009"   /* inSeqNoRef               */
#define BC_ERR_FIELD_IN_SEQ_NO                          "010"   /* inSeqNo                  */
#define BC_ERR_FIELD_ISIN_COD                           "011"   /* isinCod                  */
#define BC_ERR_FIELD_ISIN_COD_SRS                       "012"   /* isinCodSrs               */
#define BC_ERR_FIELD_ORDR_BEG_DAT_COD                   "013"   /* ordrBegDatCod            */
#define BC_ERR_FIELD_ORDR_ENT_NO                        "014"   /* ordrEntNo                */
#define BC_ERR_FIELD_ORDR_EXE_PRC                       "015"   /* ordrExePrc               */
#define BC_ERR_FIELD_ORDR_EXP_DAT                       "016"   /* ordrExpDat               */
#define BC_ERR_FIELD_ORDR_NO                            "017"   /* ordrNo                   */
#define BC_ERR_FIELD_ORDR_QTY                           "018"   /* ordrQty                  */
#define BC_ERR_FIELD_ORDR_RES_COD                       "019"   /* ordrResCod               */
#define BC_ERR_FIELD_ORDR_STOP_LIM                      "020"   /* ordrStopLim              */
#define BC_ERR_FIELD_TEXT                               "021"   /* text                     */
#define BC_ERR_FIELD_TRAD_MTCH_COD                      "022"   /* tradMtchCod              */
#define BC_ERR_FIELD_TRAD_MTCH_PRC                      "023"   /* tradMtchPrc              */
#define BC_ERR_FIELD_TRAD_MTCH_PRC_NO                   "024"   /* tradMtchPrcNo            */
#define BC_ERR_FIELD_TRAD_MTCH_QTY                      "025"   /* tradMtchQty              */
#define BC_ERR_FIELD_TRD_RES_TYP_COD                    "026"   /* trdResTypCod             */
#define BC_ERR_FIELD_USER_ORD_NUM                       "027"   /* userOrdNum               */
#define BC_ERR_FIELD_ACR_INT_DAY                        "100"   /* acrIntDay                */
#define BC_ERR_FIELD_ACR_INT_DAY_COD                    "101"   /* acrIntDayCod             */
#define BC_ERR_FIELD_BONUS_RAT                          "102"   /* bonusRat                 */
#define BC_ERR_FIELD_TRAD_NO                            "103"   /* tradNo                   */
#define BC_ERR_FIELD_BTRADE_NO          BC_ERR_FIELD_TRAD_NO    /* btradeNo                 */
#define BC_ERR_FIELD_BTRADE_NO_BID                      "106"   /* btradeNoBid              */
#define BC_ERR_FIELD_BTRADE_NO_ASK                      "107"   /* btradeNoAsk              */
#define BC_ERR_FIELD_CHANGE_QTY                         "108"   /* changeQty                */
#define BC_ERR_FIELD_CLEARING_CURR_TYP_COD              "109"   /* clearingCurrTypCod       */
#define BC_ERR_FIELD_CTPY_EXCHANGE_ID                   "110"   /* ctpyExchangeId           */
#define BC_ERR_FIELD_CTPY_NO_BID                        "111"   /* ctpyNoBid                */
#define BC_ERR_FIELD_CTPY_NO_ASK                        "112"   /* ctpyNoAsk                */
#define BC_ERR_FIELD_CTPY_SUB_NO                        "113"   /* ctpySubNo                */
#define BC_ERR_FIELD_CURR_EXC_RAT                       "114"   /* currExcRat               */
#define BC_ERR_FIELD_FEE                                "115"   /* fee                      */
#define BC_ERR_FIELD_FEE_BID                            "116"   /* feeBid                   */
#define BC_ERR_FIELD_FEE_ASK                            "117"   /* feeAsk                   */
#define BC_ERR_FIELD_FEE_FLAG                           "118"   /* feeFlag                  */
#define BC_ERR_FIELD_FEE_FLAG_BID                       "119"   /* feeFlagBid               */
#define BC_ERR_FIELD_FEE_FLAG_ASK                       "120"   /* feeFlagAsk               */
#define BC_ERR_FIELD_IW_ORD_COD                         "121"   /* iwOrdCod                 */
#define BC_ERR_FIELD_IW_ORD_COD_BID                     "122"   /* iwOrdCodBid              */
#define BC_ERR_FIELD_IW_ORD_COD_ASK                     "123"   /* iwOrdCodAsk              */
#define BC_ERR_FIELD_MATCH_FLAG_BID                     "124"   /* matchFlagBid             */
#define BC_ERR_FIELD_MATCH_FLAG_ASK                     "125"   /* matchFlagAsk             */
#define BC_ERR_FIELD_ORDR_EXE_PRC_BID                   "126"   /* ordrExePrcBid            */
#define BC_ERR_FIELD_ORDR_EXE_PRC_ASK                   "127"   /* ordrExePrcAsk            */
#define BC_ERR_FIELD_ORDR_QTY_BID                       "128"   /* ordrQtyBid               */
#define BC_ERR_FIELD_ORDR_QTY_ASK                       "129"   /* ordrQtyAsk               */
#define BC_ERR_FIELD_ORDR_EXE_PRC_MOD                   "132"   /* ordrExePrcMod            */
#define BC_ERR_FIELD_ACCT_TYP_COD_XONTRO_BID            "133"   /* acctTypCodXontroBid      */
#define BC_ERR_FIELD_ACCT_TYP_COD_XONTRO_ASK            "134"   /* acctTypCodXontroAsk      */
#define BC_ERR_FIELD_RED_QTY                            "135"   /* redQty                   */
#define BC_ERR_FIELD_TEXT_TRAD_BID                      "137"   /* textTradBid              */
#define BC_ERR_FIELD_TEXT_TRAD_ASK                      "138"   /* textTradAsk              */
#define BC_ERR_FIELD_TRAD_BEG_DAT                       "139"   /* tradBegDat               */
#define BC_ERR_FIELD_TRAD_CONT_TIM                      "140"   /* tradContTim              */
#define BC_ERR_FIELD_TRAD_CONT_DAT                      "141"   /* tradContDat              */
#define BC_ERR_FIELD_TRAD_MTCH_PRC_BID                  "143"   /* tradMtchPrcBid           */
#define BC_ERR_FIELD_TRAD_MTCH_PRC_ASK                  "144"   /* tradMtchPrcAsk           */
#define BC_ERR_FIELD_TRAN_EXCHANGE_ID                   "145"   /* tranExchangeId           */
#define BC_ERR_FIELD_VALUE_DAT                          "146"   /* valueDat                 */
#define BC_ERR_FIELD_VALUE_DAT_COD                      "147"   /* valueDatCod              */
#define BC_ERR_FIELD_FWD_ORDR_COD                       "148"   /* fwdOrdrCod               */
#define BC_ERR_FIELD_TEXT_TRAD                          "149"   /* textTrad                 */
#define BC_ERR_FIELD_MATCH_FLAG                         "150"   /* matchFlag                */
#define BC_ERR_FIELD_CONFIRM_TIM                        "151"   /* confirmTim               */
#define BC_ERR_FIELD_TRD_TYP_XONTRO                     "152"   /* trdTypXontro             */
#define BC_ERR_FIELD_POST_PROC_FLAG                     "155"   /* postProcFlag             */
#define BC_ERR_FIELD_TICKET                             "156"   /* ticket                   */
#define BC_ERR_FIELD_REP_EXCHANGE_ID                    "160"   /* repExchangeId            */
#define BC_ERR_FIELD_REP_EXCHANGE_ID_BID                "161"   /* repExchangeIdBid         */
#define BC_ERR_FIELD_REP_EXCHANGE_ID_ASK                "162"   /* repExchangeIdAsk         */
#define BC_ERR_FIELD_DEACT_COMMENT                      "163"   /* deactComment             */
#define BC_ERR_FIELD_DEACT_FROM_DAT                     "164"   /* deactFromDat             */
#define BC_ERR_FIELD_DEACT_TEXT                         "165"   /* deactText                */
#define BC_ERR_FIELD_DEACT_TO_DAT                       "166"   /* deactToDat               */
#define BC_ERR_FIELD_ISIN_COD_NEW                       "167"   /* isinCodNew               */
#define BC_ERR_FIELD_NR_COD                             "168"   /* nrCod                    */
#define BC_ERR_FIELD_NR_DAT                             "169"   /* nrDat                    */
#define BC_ERR_FIELD_CHARGES_ASK                        "170"   /* chargesAsk               */
#define BC_ERR_FIELD_CHARGES_BID                        "171"   /* chargesBid               */
#define BC_ERR_FIELD_COM_AMT_ASK                        "172"   /* comAmtAsk                */
#define BC_ERR_FIELD_COM_AMT_BID                        "173"   /* comAmtBid                */
#define BC_ERR_FIELD_COM_COD_ASK                        "174"   /* comCodAsk                */
#define BC_ERR_FIELD_COM_COD_BID                        "175"   /* comCodBid                */
#define BC_ERR_FIELD_COM_RATE_ASK                       "176"   /* comRateAsk               */
#define BC_ERR_FIELD_COM_RATE_BID                       "177"   /* comRateBid               */
#define BC_ERR_FIELD_EXCHANGE_ORD_NUM                   "178"   /* exchangeOrdNum           */
#define BC_ERR_FIELD_ORIG_ORDR_QTY                      "179"   /* origOrdrQty              */
#define BC_ERR_FIELD_ON_BEHALF_CTPY_NO_ASK              "180"   /* onBehalfCtpyNoAsk        */
#define BC_ERR_FIELD_ON_BEHALF_CTPY_NO_BID              "181"   /* onBehalfCtpyNoBid        */
#define BC_ERR_FIELD_ORDR_BK_EXE_QTY                    "182"   /* ordrBkExeQty             */
#define BC_ERR_FIELD_REF_TIM                            "183"   /* refTim                   */
#define BC_ERR_FIELD_CUSTOMER_ID_CLASS                  "185"   /* customerIdClass          */
#define BC_ERR_FIELD_CUSTOMER_ID                        "186"   /* customerId               */
#define BC_ERR_FIELD_COMMISSION_AGENT_FLAG              "187"   /* commissionAgentFlag      */
#define BC_ERR_FIELD_SETTLEMENT_FLAG                    "188"   /* settlementFlag           */
#define BC_ERR_FIELD_ALERT_COD                          "189"   /* alertCod                 */
#define BC_ERR_FIELD_AMEND_IND                          "190"   /* amendInd                 */
#define BC_ERR_FIELD_BIC_ENT_COD                        "191"   /* bicEntCod                */
#define BC_ERR_FIELD_DELAY_IND                          "192"   /* delayInd                 */
#define BC_ERR_FIELD_DIFF_PRC_IND                       "193"   /* diffPrcInd               */
#define BC_ERR_FIELD_DIS_TIME_STAMP                     "194"   /* disTimeStamp             */
#define BC_ERR_FIELD_EXEC_VENUE_ID                      "195"   /* execVenueId              */
#define BC_ERR_FIELD_NEGO_PRC_IND                       "196"   /* negoPrcInd               */
#define BC_ERR_FIELD_PUB_TYPE                           "197"   /* pubType                  */
#define BC_ERR_FIELD_REC_TIME_STAMP                     "198"   /* recTimeStamp             */
#define BC_ERR_FIELD_TRAN_CONT_DAT                      "199"   /* tranContDat              */
#define BC_ERR_FIELD_TRAN_CONT_TIM                      "200"   /* tranContTim              */
#define BC_ERR_FIELD_UNT_OF_TRAD                        "201"   /* untOfTrad                */
#define BC_ERR_FIELD_USER_TRAD_NUM                      "202"   /* userTradNum              */
#define BC_ERR_FIELD_UTC_DIFF                           "203"   /* utcDiff                  */
#define BC_ERR_FIELD_XONTRO_REPO_NO                     "204"   /* xontroRepoNo             */
#define BC_ERR_FIELD_TRAN_FEE_FLAG_ASK                  "205"   /* tranFeeFlagAsk           */
#define BC_ERR_FIELD_TRAN_FEE_FLAG_BID                  "206"   /* tranFeeFlagBid           */
#define BC_ERR_FIELD_TRAN_FEE_ASK                       "207"   /* tranFeeAsk               */
#define BC_ERR_FIELD_TRAN_FEE_BID                       "208"   /* tranFeeBid               */
#define BC_ERR_FIELD_CURR_TYP_COD                       "209"   /* currTypCod               */
#define BC_ERR_FIELD_TRAN_FEE_FLAG                      "210"   /* tranFeeFlag              */
#define BC_ERR_FIELD_TRAN_FEE                           "211"   /* tranFee                  */
#define BC_ERR_FIELD_CHECK_EXE_QTY_BID                  "212"   /* checkExeQtyBid           */
#define BC_ERR_FIELD_CHECK_EXE_QTY_ASK                  "213"   /* checkExeQtyAsk           */
#define BC_ERR_FIELD_CHECK_EXE_PRC_BID                  "214"   /* checkExePrcBid           */
#define BC_ERR_FIELD_CHECK_EXE_PRC_ASK                  "215"   /* checkExePrcAsk           */
#define BC_ERR_FIELD_POSS_LOCK_FLAG                     "216"   /* possLockFlag             */
#define BC_ERR_FIELD_ORDR_STAT_COD                      "217"   /* ordrStatCod              */
#define BC_ERR_FIELD_PROCESSING_COD                     "218"   /* processingCod            */
#define BC_ERR_FIELD_ALLOT_CAP_QTY                      "220"   /* allotCapQty              */
#define BC_ERR_FIELD_ALLOT_TYPE                         "221"   /* allotType                */
#define BC_ERR_FIELD_CLIENT_IND                         "230"   /* clientInd                */
#define BC_ERR_FIELD_CLIENT_COD                         "231"   /* clientCod                */
#define BC_ERR_FIELD_EXECUTION_IND                      "232"   /* executionInd             */
#define BC_ERR_FIELD_EXECUTION_COD                      "233"   /* executionCod             */
#define BC_ERR_FIELD_INVESTMENT_IND                     "234"   /* investmentInd            */
#define BC_ERR_FIELD_INVESTMENT_COD                     "235"   /* investmentCod            */
#define BC_ERR_FIELD_DEA_FLAG                           "236"   /* deaFlag                  */
#define BC_ERR_FIELD_KILL_FLAG                          "237"   /* killFlag                 */
#define BC_ERR_FIELD_LIQUIDITY_PROV_FLAG                "238"   /* liquidityProvFlag        */
#define BC_ERR_FIELD_OPT_OUT_FLAG                       "239"   /* optOutFlag               */
#define BC_ERR_FIELD_OTC_POST_TRAD_IND                  "240"   /* otcPostTradInd           */
#define BC_ERR_FIELD_QUOTE_TIME_STAMP                   "241"   /* quoteTimeStamp           */
#define BC_ERR_FIELD_SHORT_SELL_COD                     "242"   /* shortSellCod             */
#define BC_ERR_FIELD_TRAD_CAPACITY_COD                  "243"   /* tradCapacityCod          */
#define BC_ERR_FIELD_TRAD_CONT_TIM_FRACTION             "244"   /* tradContTimFraction      */
#define BC_ERR_FIELD_TVTIC                              "245"   /* tvTic                    */
#define BC_ERR_FIELD_QUOTE_SEQ_NO                       "246"   /* quoteSeqNo               */


/* return code constants VALUES API */

#define ELB_BC_NOT_AVAILABLE              23500
#define ELB_BC_PRICING_BE                 25420
#define ELB_BC_FINISH_PRICING_BE          27180
#define ELB_BC_PRICE_FIXING               29010
#define ELB_BC_ORDER_EX                   29020
#define ELB_BC_ORDER_NOEX                 29030
#define ELB_BC_SEQNO_EX                   29040
#define ELB_BC_BTRADE_ERROR               29050
#define ELB_BC_CONTINGENT_EXHAUSTED       29090
#define ELB_BC_DUPLICATE_ISIN             29300
#define ELB_BC_QUOTING_STOPPED            29390
#define ELB_BC_CONFIRM_TIM_OUTDATED       29700
#define ELB_BC_INSEQNO_OUTDATED           29710
#define ELB_BC_DEFAULT                    29999


/* quoteReturnCod for quote bypass */

#define BYPASS_MESSAGE_OK_PUBLISHED            'Y'
#define BYPASS_QUOTE_INVALID_CONFIRM_TIM       'F'
#define BYPASS_QUOTE_VOLUME_OVERFLOW           'V'
#define BYPASS_QUOTE_LOGIN_MISSING             'L'
#define BYPASS_QUOTE_SEQNO_NOT_ASCENDING       'S'
#define BYPASS_QUOTE_SYNTAX_ERROR              'X'


/* field length constants */

#define TIME_LEN_BOSS        8 /* HHMMSSCC  */
#define TIME_STAMP_BOSS     12 /* HHMMSSCCCCCC */
#define DATE_LEN_BOSS        8 /* CCYYMMDD  */
#define PRICE_BOSS          10 /* num  10,4 */
#define LIMIT_BOSS          10 /* num  10,4 */
#define VOLUME_BOSS         13 /* num  13,3 */
#define AMOUNT_BOSS         16 /* Snum 16,2 */


/* layouts */

typedef struct
{
    char    qsamId[4];
    char    qsamMsgType[1];
    char    qsamRequestId[3];
    char    qsamExchangeId[3];
    char    qsamUserId[10];
}   bc_qsam_request_headerT;

typedef struct
{
    char    qsamId[4];
    char    qsamMsgType[1];
    char    qsamRequestId[3];
    char    qsamExchangeId[3];
    char    qsamUserId[10];
    char    qsamComplCode[5];
}   bc_qsam_response_headerT;

typedef struct
{
    char    qsamId[4];
    char    qsamMsgType[1];
    char    qsamExchangeId[3];
    char    qsamDat[DATE_LEN_BOSS];
    char    qsamBrkNo[4];
    char    qsamStreamId[2];
}   bc_qsam_broadcast_headerT;

typedef struct
{
    char    inSeqNo[9];
}   bc_request_headerT;

typedef struct
{
    char    tranDat[DATE_LEN_BOSS];
    char    tranTim[TIME_LEN_BOSS];
    char    execTranDat[DATE_LEN_BOSS];
    char    execTranTim[TIME_LEN_BOSS];
    char    errFieldRef[3];
    char    inSeqNo[9];
}   bc_response_headerT;

typedef struct
{
    char    tranDat[DATE_LEN_BOSS];
    char    tranTim[TIME_LEN_BOSS];
    char    execTranDat[DATE_LEN_BOSS];
    char    execTranTim[TIME_LEN_BOSS];
    char    errFieldRef[3];
    char    outSeqNo[9];
    char    bkrUserNo[4];
    char    isinCod[12];
    char    subType[3];
}   bc_broadcast_headerT;

typedef struct
{
    char    bcOldPwd[8];
    char    bcNewPwd[8];
}   bc_request_change_pwdT;

typedef struct
{
    char    acctTypCodXontro[2];
    char    bkrNo[4];
    char    buyCod;
    char    ctpyNo[4];
    char    isinCod[12];
    char    isinCodSrs[12];
    char    ordrExePrc[PRICE_BOSS];
    char    ordrExpDat[DATE_LEN_BOSS];
    char    ordrQty[VOLUME_BOSS];
    char    ordrResCod[3];
    char    ordrStopLim[LIMIT_BOSS];
    char    text[25];
    char    trdResTypCod[2];
    char    userOrdNum[16];
    char    fwdOrdrCod;
    char    netTypCodXontro;
    char    clientInd[1];
    char    clientCod[20];
    char    investmentInd[1];
    char    investmentCod[20];
    char    executionInd[1];
    char    executionCod[20];
    char    deaFlag[1];
    char    tradCapacityCod[1];
    char    optOutFlag[1];
    char    liquidityProvFlag[1];
}   bc_request_ent_ordT;

typedef struct
{
    char    bkrNo[4];
    char    isinCod[12];
    char    isinCodSrs[12];
    char    ordrNo[13];
    char    trdResTypCod[2];
    char    fwdOrdrNo[13];
}   bc_response_ent_ordT;

typedef struct
{
    char    isinCod[12];
    char    ordrExePrc[PRICE_BOSS];
    char    ordrExpDat[DATE_LEN_BOSS];
    char    ordrNo[13];
    char    ordrQty[VOLUME_BOSS];
    char    ordrStopLim[LIMIT_BOSS];
    char    text[25];
    char    ordrStatCod;
    char    clientInd[1];
    char    clientCod[20];
    char    investmentInd[1];
    char    investmentCod[20];
    char    executionInd[1];
    char    executionCod[20];
    char    deaFlag[1];
    char    optOutFlag[1];
}   bc_request_mod_ordT;

typedef struct
{
    char    isinCod[12];
    char    ordrNo[13];
}   bc_response_mod_ordT;

typedef struct
{
    char    isinCod[12];
    char    ordrNo[13];
    char    clientInd[1];
    char    clientCod[20];
    char    investmentInd[1];
    char    investmentCod[20];
    char    executionInd[1];
    char    executionCod[20];
    char    killFlag[1];
}   bc_request_del_ordT;


typedef struct
{
    char    subType[3];
}   bc_subTypeT;

typedef struct
{
    char    acctTypCodXontro[2];
    char    bkrNo[4];
    char    buyCod;
    char    ctpyNo[4];
    char    fwdOrdrNo[13];
    char    isinCod[12];
    char    isinCodSrs[12];
    char    ordrBegDatCod;
    char    ordrEntNo[4];
    char    ordrExePrc[PRICE_BOSS];
    char    ordrExpDat[DATE_LEN_BOSS];
    char    ordrNo[13];
    char    ordrQty[VOLUME_BOSS];
    char    ordrResCod[3];
    char    ordrStopLim[LIMIT_BOSS];
    char    text[25];
    char    trdResTypCod[2];
    char    userNo[10];
    char    userOrdNum[16];
    char    netTypCodXontro;
    char    regulatoryID[10];
}   bc_orderT;

typedef struct
{
    char    acctTypCodXontro[2];
    char    bkrNo[4];
    char    buyCod;
    char    ctpyNo[4];
    char    fwdOrdrNo[13];
    char    isinCod[12];
    char    isinCodSrs[12];
    char    ordrBegDatCod;
    char    ordrEntNo[4];
    char    ordrExePrc[PRICE_BOSS];
    char    ordrExpDat[DATE_LEN_BOSS];
    char    ordrNo[13];
    char    ordrQty[VOLUME_BOSS];
    char    ordrResCod[3];
    char    ordrStopLim[LIMIT_BOSS];
    char    text[25];
    char    trdResTypCod[2];
    char    userNo[10];
    char    userOrdNum[16];
    char    netTypCodXontro;
}   bc_response_inq_ordT;

typedef struct
{
    char    nrCod[4];
    char    ordrExePrc[PRICE_BOSS];
    char    ordrNo[13];
    char    userNo[10];
}   bc_nrT;

typedef struct
{
    char    bkrUserNo[4];
}   bc_private_subjectT;

typedef struct
{
    char    userNo[10];
    char    pwExpirationDat[DATE_LEN_BOSS];
}   bc_brd_pw_expiration_datT;

typedef struct
{
    char    ordrExePrc[PRICE_BOSS];
    char    ordrExpDat[DATE_LEN_BOSS];
    char    ordrNo[13];
    char    ordrQty[VOLUME_BOSS];
    char    ordrStopLim[LIMIT_BOSS];
    char    text[25];
    char    userNo[10];
    char    ctpyNo[4];
    char    ordrStatCod;
    char    regulatoryID[10];
}   bc_brd_mod_orderT;

typedef struct
{
    char    ordrNo[13];
    char    userNo[10];
    char    ordrQty[VOLUME_BOSS];
    char    ordrStatCod;
    char    regulatoryID[10];
}   bc_brd_del_orderT;

typedef struct
{
    char    startStmSeqNo[9];
    char    stopStmSeqNo[9];
}   bc_request_retransT;

typedef struct
{
    char    execConfType[3];
    char    ordrNo[13];
    char    userOrdNum[16];
    char    tradMtchCod[3];
    char    tradMtchPrc[PRICE_BOSS];
    char    tradMtchPrcNo[5];
    char    tradMtchQty[VOLUME_BOSS];
    char    tradMtchPrcTim[TIME_LEN_BOSS];
    char    tradMtchPrcTimFraction[4];
    char    tradMtchPrcDat[DATE_LEN_BOSS];
    char    trdResTypCod[2];
    char    userNo[10];
    char    tvTic[52];
    char    algoFlag[1];
}   bc_brd_exec_confT;

typedef struct
{
    char    tradMtchCod[3];
    char    tradMtchPrc[PRICE_BOSS];
    char    tradMtchPrcNo[5];
    char    trdResTypCod[2];
}   bc_brd_end_execT;

typedef struct
{
    char    bcPwd[8];
}   bc_pwdT;

typedef struct
{
    char    tradMtchCod[3];
    char    tradMtchPrc[PRICE_BOSS];
    char    tradMtchPrcNo[5];
    char    trdResTypCod[2];
    char    lockTim[TIME_LEN_BOSS];
    char    confirmTim[TIME_LEN_BOSS];
    char    ordrBkExeQty[16];
    char    postProcFlag;
    char    tradMtchPrcTim[TIME_LEN_BOSS];
    char    tradMtchPrcTimFraction[4];
    char    tradMtchPrcDat[DATE_LEN_BOSS];
    char    venueMic[4];
}   bc_brd_ent_priceT;

typedef struct
{
    char    userNo[10];
    char    ticket[9];
    char    lockTim[TIME_LEN_BOSS];
    char    confirmTim[TIME_LEN_BOSS];
    char    trdResTypCod[2];
    char    tradMtchCod[3];
    char    tradMtchPrc[PRICE_BOSS];
    char    tradMtchPrcNo[5];
    char    tradMtchPrcTim[TIME_LEN_BOSS];
    char    tradMtchPrcTimFraction[4];
    char    tradMtchPrcDat[DATE_LEN_BOSS];
    char    ordrBkExeQty[16];
    char    postProcFlag;
    char    ctpyNoBid[4];
    char    ctpyNoAsk[4];
    char    tradMtchQty[VOLUME_BOSS];
    char    feeFlag[2];
    char    fee[10];
    char    tranFeeFlag[2];
    char    tranFee[10];
    char    currExcRat[10];
    char    inSeqNoRef[9];
    char    venueMic[4];
}   bc_brd_ent_price_plusT;

typedef struct
{
    char    isinCod[12];
    char    tradMtchCod[3];
    char    tradMtchPrc[PRICE_BOSS];
    char    tradMtchPrcNo[5];
    char    trdResTypCod[2];
    char    lockTim[TIME_LEN_BOSS];
    char    tradMtchPrcTim[TIME_LEN_BOSS];
    char    tradMtchPrcTimFraction[4];
    char    tradMtchPrcDat[DATE_LEN_BOSS];
    char    venueMic[4];
}   bc_brd_ent_block_priceT;

typedef struct
{
    char    isinCod[12];
    char    deactFromDat[DATE_LEN_BOSS];
    char    deactToDat[DATE_LEN_BOSS];
}   bc_brd_pricing_blockT;

typedef struct
{
    char    tradMtchCod[3];
    char    tradMtchPrc[PRICE_BOSS];
    char    tradMtchPrcNo[5];
    char    trdResTypCod[2];
    char    currExcRat[10];
} bc_brd_finish_pricingT;

typedef struct
{
    char    lockTim[TIME_LEN_BOSS];
    char    trdResTypCod[2];
    char    userNo[10];
}   bc_brd_unlockT;

typedef struct
{
    char    confirmTim[TIME_LEN_BOSS];
}   bc_brd_confirm_timT;

typedef struct
{
    char    confirmTimBypass[TIME_LEN_BOSS];
}   bc_brd_confirm_tim_bypassT;

typedef struct
{
    char    quoteType;
    char    quoteStatus;
    char    ordrExePrcAsk[PRICE_BOSS];
    char    ordrQtyAsk[VOLUME_BOSS];
    char    ordrVolAsk[10];
    char    ordrExePrcBid[PRICE_BOSS];
    char    ordrQtyBid[VOLUME_BOSS];
    char    ordrVolBid[10];
    char    confirmTim[TIME_LEN_BOSS];
    char    quoteTimeStamp[TIME_STAMP_BOSS];
}   bc_brd_ent_quoteT;

typedef struct
{
    char    confirmTim[TIME_LEN_BOSS];
    char    quoteTimeStamp[TIME_STAMP_BOSS];
}   bc_brd_deact_quoteT;

typedef struct
{
    char    ordrExePrcAsk[PRICE_BOSS];
    char    ordrQtyAsk[VOLUME_BOSS];
    char    ordrExePrcBid[PRICE_BOSS];
    char    ordrQtyBid[VOLUME_BOSS];
    char    inSeqNo[9];
    char    quoteTimeStamp[TIME_STAMP_BOSS];
}   bc_brd_ent_quote_feT;

typedef struct
{
    char    inSeqNo[9];
    char    quoteTimeStamp[TIME_STAMP_BOSS];
}   bc_brd_deact_quote_feT;

typedef struct
{
    char    isinCod[12];
    char    ordrExePrcAsk[PRICE_BOSS];
    char    ordrQtyAsk[VOLUME_BOSS];
    char    ordrExePrcBid[PRICE_BOSS];
    char    ordrQtyBid[VOLUME_BOSS];
    char    confirmTim[TIME_LEN_BOSS];
    char    quoteTimeStamp[TIME_STAMP_BOSS];
}   bc_request_ent_quoteT;

typedef struct
{
    char    inSeqNoCurrent[9];
    char    confirmTimCurrent[TIME_LEN_BOSS];
    char    bkrQuoteVolRemain[9];
}   bc_response_ent_quoteT;

typedef struct
{
    char    bypassQuoteVolAct[9];
    char    bypassQuoteVolMax[9];
}   bc_brd_bypass_quote_volume_infoT;

typedef struct
{
    char    btradeNo[13];
    char    bkrNo[4];
    char    bkrSubNo[2];
    char    exchangeId[3];
    char    buyCod;
    char    ctpyNo[4];
    char    ctpySubNo[2];
    char    ctpyExchangeId[3];
    char    ctpyLei[20];
    char    tranExchangeId[3];
    char    btradeCod;
    char    tradMtchPrc[PRICE_BOSS];
    char    tradMtchQty[VOLUME_BOSS];
    char    ordrQty[VOLUME_BOSS];
    char    clearingCurrTypCod[3];
    char    currExcRat[10];
    char    valueDatCod[2];
    char    valueDat[DATE_LEN_BOSS];
    char    acrIntDay[4];
    char    acrIntDayCod[2];
    char    bonusRat[6];
    char    tradMtchPrcNo[5];
    char    acctTypCodXontro[2];
    char    iwOrdCod[2];
    char    isinCod[12];
    char    isinCodSrs[12];
    char    tradBegDat[DATE_LEN_BOSS];
    char    tradContTim[TIME_LEN_BOSS];
    char    tradContTimFraction[4];
    char    tradContDat[DATE_LEN_BOSS];
    char    repExchangeId[3];
    char    trdTypXontro[2];
    char    tvTic[52];
    char    venueMic[4];
    char    shortSellCod[2];
    char    otcPostTradInd[3];
}   bc_btradeT;

typedef bc_btradeT bc_brd_ent_btradeT;

typedef struct
{
    char    btradeNo[13];
    char    bkrNo[4];
    char    bkrSubNo[2];
    char    exchangeId[3];
    char    buyCod;
    char    ctpyNo[4];
    char    ctpySubNo[2];
    char    ctpyExchangeId[3];
    char    ctpyLei[20];
    char    tranExchangeId[3];
    char    btradeCod;
    char    tradMtchPrc[PRICE_BOSS];
    char    tradMtchQty[VOLUME_BOSS];
    char    ordrQty[VOLUME_BOSS];
    char    clearingCurrTypCod[3];
    char    currExcRat[10];
    char    valueDatCod[2];
    char    valueDat[DATE_LEN_BOSS];
    char    acrIntDay[4];
    char    acrIntDayCod[2];
    char    bonusRat[6];
    char    tradMtchPrcNo[5];
    char    acctTypCodXontro[2];
    char    iwOrdCod[2];
    char    isinCod[12];
    char    isinCodSrs[12];
    char    tradBegDat[DATE_LEN_BOSS];
    char    tradContTim[TIME_LEN_BOSS];
    char    tradContTimFraction[4];
    char    tradContDat[DATE_LEN_BOSS];
    char    repExchangeId[3];
    char    inSeqNoRef[9];
    char    trdTypXontro[2];
    char    tvTic[52];
    char    venueMic[4];
    char    shortSellCod[2];
    char    otcPostTradInd[3];
}   bc_brd_ent_btrade_feT;

typedef struct
{
    char    btradeNo[13];
    char    bkrNo[4];
    char    bkrSubNo[2];
    char    exchangeId[3];
    char    buyCod;
    char    ctpyNo[4];
    char    ctpySubNo[2];
    char    ctpyExchangeId[3];
    char    ctpyLei[20];
    char    tranExchangeId[3];
    char    btradeCod;
    char    tradMtchPrc[PRICE_BOSS];
    char    tradMtchQty[VOLUME_BOSS];
    char    ordrQty[VOLUME_BOSS];
    char    clearingCurrTypCod[3];
    char    currExcRat[10];
    char    valueDatCod[2];
    char    valueDat[DATE_LEN_BOSS];
    char    acrIntDay[4];
    char    acrIntDayCod[2];
    char    bonusRat[6];
    char    tradMtchPrcNo[5];
    char    acctTypCodXontro[2];
    char    iwOrdCod[2];
    char    isinCod[12];
    char    isinCodSrs[12];
    char    tradBegDat[DATE_LEN_BOSS];
    char    tradContTim[TIME_LEN_BOSS];
    char    tradContTimFraction[4];
    char    tradContDat[DATE_LEN_BOSS];
    char    repExchangeId[3];
    char    feeFlag[2];
    char    fee[10];
    char    textTrad[35];
    char    ctpyTradMtchPrc[PRICE_BOSS];
    char    trdTypXontro[2];
    char    tvTic[52];
    char    venueMic[4];
    char    shortSellCod[2];
    char    otcPostTradInd[3];
}   bc_btrade_2T;

typedef bc_btrade_2T bc_brd_ent_btrade_2T;

typedef struct
{
    char    btradeNo[13];
    char    bkrNo[4];
    char    bkrSubNo[2];
    char    exchangeId[3];
    char    buyCod;
    char    ctpyNo[4];
    char    ctpySubNo[2];
    char    ctpyExchangeId[3];
    char    ctpyLei[20];
    char    tranExchangeId[3];
    char    btradeCod;
    char    tradMtchPrc[PRICE_BOSS];
    char    tradMtchQty[VOLUME_BOSS];
    char    ordrQty[VOLUME_BOSS];
    char    clearingCurrTypCod[3];
    char    currExcRat[10];
    char    valueDatCod[2];
    char    valueDat[DATE_LEN_BOSS];
    char    acrIntDay[4];
    char    acrIntDayCod[2];
    char    bonusRat[6];
    char    tradMtchPrcNo[5];
    char    acctTypCodXontro[2];
    char    iwOrdCod[2];
    char    isinCod[12];
    char    isinCodSrs[12];
    char    tradBegDat[DATE_LEN_BOSS];
    char    tradContTim[TIME_LEN_BOSS];
    char    tradContTimFraction[4];
    char    tradContDat[DATE_LEN_BOSS];
    char    repExchangeId[3];
    char    feeFlag[2];
    char    fee[10];
    char    textTrad[35];
    char    inSeqNoRef[9];
    char    ctpyTradMtchPrc[PRICE_BOSS];
    char    trdTypXontro[2];
    char    tvTic[52];
    char    venueMic[4];
    char    shortSellCod[2];
    char    otcPostTradInd[3];
}   bc_brd_ent_btrade_fe_2T;

typedef struct
{
    char    bkrNo[4];
    char    buyCod;
    char    ctpyNo[4];
    char    tradMtchPrc[PRICE_BOSS];
    char    tradMtchQty[VOLUME_BOSS];
    char    currExcRat[10];
    char    valueDatCod[2];
    char    valueDat[DATE_LEN_BOSS];
    char    acrIntDay[4];
    char    acrIntDayCod[2];
    char    bonusRat[6];
    char    acctTypCodXontro[2];
    char    matchFlag[2];
    char    iwOrdCod[2];
    char    isinCod[12];
    char    feeFlag[2];
    char    fee[10];
    char    textTrad[35];
    char    tradBegDat[DATE_LEN_BOSS];
    char    tradContTim[TIME_LEN_BOSS];
    char    tradContDat[DATE_LEN_BOSS];
    char    trdTypXontro[2];
    char    repExchangeId[3];
    char    shortSellCod[2];
}   bc_request_ent_btradeT;

typedef struct
{
    char    btradeNo[13];
    char    isinCod[12];
}   bc_brd_del_btradeT;

typedef bc_brd_del_btradeT  bc_brd_can_btradeT;
typedef bc_brd_del_btradeT  bc_request_del_btradeT;

typedef struct
{
    char    btradeNo[13];
    char    changeQty[1+VOLUME_BOSS];
    char    isinCod[12];
}   bc_brd_mod_btradeT;

typedef bc_brd_mod_btradeT  bc_brd_match_btradeT;

typedef struct
{
    char    btradeNo[13];
    char    isinCod[12];
    char    inSeqNoRef[9];
}   bc_brd_del_btrade_feT;

typedef bc_brd_del_btrade_feT bc_brd_can_btrade_feT;

typedef struct
{
    char    btradeNoAsk[13];
    char    btradeNoBid[13];
    char    ctpyNo[4];
    char    tradMtchPrc[PRICE_BOSS];
    char    redQty[VOLUME_BOSS];
    char    isinCod[12];
    char    feeFlag[2];
    char    fee[10];
    char    currExcRat[10];
    char    acctTypCodXontro[2];
    char    tradBegDat[DATE_LEN_BOSS];
    char    tradContTim[TIME_LEN_BOSS];
    char    tradContDat[DATE_LEN_BOSS];
    char    trdTypXontro[2];
    char    repExchangeId[3];
    char    customerIdClass;
    char    customerId[8];
    char    commissionAgentFlag;
    char    settlementFlag[2];
    char    textTrad[35];
}   bc_request_match_btradeT;

typedef struct
{
    char    isinCod[12];
}   bc_request_match_all_btradesT;

typedef struct
{
    char    buyCod;
    char    tradMtchPrc[PRICE_BOSS];
    char    tradMtchQty[VOLUME_BOSS];
    char    tradMtchPrcNo[5];
    char    isinCod[12];
    char    isinCodSrs[12];
    char    tradEnterDat[DATE_LEN_BOSS];
}   bc_brd_ent_temp_btradeT;

typedef struct
{
    char    buyCod;
    char    changeQty[1+VOLUME_BOSS];
    char    tradMtchPrcNo[5];
    char    isinCod[12];
}   bc_brd_mod_temp_btradeT;

typedef bc_brd_mod_temp_btradeT  bc_brd_del_temp_btradeT;

typedef struct
{
    char    btradeNo[13];
    char    changeQty[1+VOLUME_BOSS];
    char    isinCod[12];
    char    inSeqNoRef[9];
}   bc_brd_match_btrade_feT;

typedef struct
{
    char    isinCod[12];
    char    tradMtchPrc[PRICE_BOSS];
    char    bkrNo[4];
    char    tradMtchQty[VOLUME_BOSS];
    char    tradBegDat[DATE_LEN_BOSS];
    char    tradContTim[TIME_LEN_BOSS];
    char    tradContDat[DATE_LEN_BOSS];
    char    currExcRat[10];
    char    acrIntDay[4];
    char    acrIntDayCod[2];
    char    bonusRat[6];
    char    valueDatCod[2];
    char    valueDat[DATE_LEN_BOSS];
    char    trdTypXontro[2];
    char    settlementFlag[2];
    char    shortSellCod[2];

    char    ctpyNoAsk[4];
    char    btradeNoAsk[13];
    char    matchFlagAsk[2];
    char    acctTypCodXontroAsk[2];
    char    iwOrdCodAsk[2];
    char    tradMtchPrcAsk[PRICE_BOSS];
    char    feeFlagAsk[2];
    char    feeAsk[10];
    char    tranFeeFlagAsk[2];
    char    tranFeeAsk[10];
    char    repExchangeIdAsk[3];
    char    textTradAsk[35];

    char    ctpyNoBid[4];
    char    btradeNoBid[13];
    char    matchFlagBid[2];
    char    acctTypCodXontroBid[2];
    char    iwOrdCodBid[2];
    char    tradMtchPrcBid[PRICE_BOSS];
    char    feeFlagBid[2];
    char    feeBid[10];
    char    tranFeeFlagBid[2];
    char    tranFeeBid[10];
    char    repExchangeIdBid[3];
    char    textTradBid[35];
}   bc_request_enter_single_tradeT;

typedef struct
{
    char    tradCod[2];
    char    isinCod[12];
    char    tradMtchQty[VOLUME_BOSS];
    char    tradMtchPrc[PRICE_BOSS];
    char    ctpyNo[4];
    char    tradTimeStamp[12];
}   bc_brd_own_tradeT;

typedef struct
{
    char    deactFromDat[DATE_LEN_BOSS];
    char    deactToDat[DATE_LEN_BOSS];
}   bc_brd_dea_pricingT;

typedef struct
{
    char    acctTypCodXontro[2];
    char    bkrNo[4];
    char    buyCod;
    char    ctpyNo[4];
    char    fwdOrdrNo[13];
    char    isinCod[12];
    char    isinCodSrs[12];
    char    ordrBegDatCod;
    char    ordrEntNo[4];
    char    ordrExePrc[PRICE_BOSS];
    char    ordrExpDat[DATE_LEN_BOSS];
    char    ordrNo[13];
    char    ordrQty[VOLUME_BOSS];
    char    ordrResCod[3];
    char    ordrStopLim[LIMIT_BOSS];
    char    text[25];
    char    trdResTypCod[2];
    char    userNo[10];
    char    userOrdNum[16];
    char    netTypCodXontro;
    char    lockTim[TIME_LEN_BOSS];
    char    regulatoryID[10];
}   bc_brd_pend_ent_orderT;

typedef struct
{
    char    ordrExePrc[PRICE_BOSS];
    char    ordrExpDat[DATE_LEN_BOSS];
    char    ordrNo[13];
    char    ordrQty[VOLUME_BOSS];
    char    ordrStopLim[LIMIT_BOSS];
    char    text[25];
    char    userNo[10];
    char    lockTim[TIME_LEN_BOSS];
    char    lockFlag;
    char    pendFlag;
    char    ctpyNo[4];
    char    regulatoryID[10];
}   bc_brd_pend_mod_orderT;

typedef struct
{
    char    ordrNo[13];
    char    userNo[10];
    char    lockTim[TIME_LEN_BOSS];
    char    lockFlag;
    char    pendFlag;
    char    regulatoryID[10];
}   bc_brd_pend_del_orderT;

/* Broker Diary Broadcast */

typedef struct
{
    char    acctTypCodXontroAsk[2];
    char    acctTypCodXontroBid[2];
    char    acrIntDay[4];
    char    acrIntDayCod[2];
    char    bkrDiaryNo[3];
    char    bkrSubNo[2];
    char    bkrUserNo[4];
    char    bonusDifAmtAsk[10];
    char    bonusDifAmtBid[10];
    char    bonusRat[6];
    char    bonusRatAsk[6];
    char    bonusRatBid[6];
    char    btradeCodAsk;
    char    btradeCodBid;
    char    btradeEnfCod;
    char    btradeTextAsk[3];
    char    btradeTextBid[3];
    char    busDat[DATE_LEN_BOSS];
    char    clearingCurrTypCod[3];
    char    ctpyNoAsk[4];
    char    ctpyLeiAsk[20];
    char    ctpyNoBid[4];
    char    ctpyLeiBid[20];
    char    currExcRat[10];
    char    currExcRatAsk[10];
    char    currExcRatBid[10];
    char    eccpCod;
    char    exchangeIdAsk[3];
    char    exchangeIdBid[3];
    char    feeAsk[10];
    char    feeBid[10];
    char    feeFlagAsk[2];
    char    feeFlagBid[2];
    char    tranFeeAsk[10];
    char    tranFeeBid[10];
    char    tranFeeFlagAsk[2];
    char    tranFeeFlagBid[2];
    char    humNo[4];
    char    isinCod[12];
    char    iwOrdCodAsk[2];
    char    iwOrdCodBid[2];
    char    textTradAsk[35];
    char    textTradBid[35];
    char    tradBegDat[DATE_LEN_BOSS];
    char    tradClCod;
    char    tradClearingPrc[PRICE_BOSS];
    char    tradDifAmtAsk[AMOUNT_BOSS];
    char    tradDifAmtBid[AMOUNT_BOSS];
    char    tradMtchPrc[PRICE_BOSS];
    char    tradMtchPrcAsk[PRICE_BOSS];
    char    tradMtchPrcBid[PRICE_BOSS];
    char    tradMtchPrcNoAsk[5];
    char    tradMtchPrcNoBid[5];
    char    tradMtchPrcType;
    char    tradMtchQty[VOLUME_BOSS];
    char    tradNo[13];
    char    tradNoAsk[13];
    char    tradNoBid[13];
    char    tradNoOld[13];
    char    tradTim[TIME_LEN_BOSS];
    char    tranContDatAsk[DATE_LEN_BOSS];
    char    tranContDatBid[DATE_LEN_BOSS];
    char    tranContTimAsk[TIME_LEN_BOSS];
    char    tranContTimFractionAsk[4];
    char    tranContTimBid[TIME_LEN_BOSS];
    char    tranContTimFractionBid[4];
    char    tranExchangeId[3];
    char    trdTypXontroAsk[2];
    char    trdTypXontroBid[2];
    char    userNo[10];
    char    valueDat[DATE_LEN_BOSS];
    char    valueDatCod[2];
    char    xontroOdrCodAsk[2];
    char    xontroOdrCodBid[2];
    char    repExchangeIdAsk[3];
    char    repExchangeIdBid[3];
    char    customerIdClassAsk;
    char    customerIdClassBid;
    char    customerIdAsk[8];
    char    customerIdBid[8];
    char    commissionAgentFlagAsk;
    char    commissionAgentFlagBid;
    char    settlementFlag[2];
    char    tvTicAsk[52];
    char    tvTicBid[52];
    char    venueMic[4];
    char    shortSellCod[2];
    char    otcPostTradIndAsk[3];
    char    otcPostTradIndBid[3];
}   bc_diaryT;

typedef struct
{
    char    bKeyInq[9];
}   bc_key_inquireT;

typedef struct
{
    char    nrCod[4];
    char    isinCod[12];
    char    isinCodNew[12];
    char    ordrExePrcMod[11];
    char    nrDat[DATE_LEN_BOSS];
}   bc_sp_rightT;

typedef struct
{
    char    isinCod[12];
    char    tradMtchCod[3];
    char    tradMtchPrc[PRICE_BOSS];
    char    trdResTypCod[2];
}   bc_request_ent_block_priceT;

typedef struct
{
    char    maxNoPrc[3];
}   bc_response_ent_block_price_noT;

typedef struct
{
    char    isinCod[12];
    char    errCod[9];
}   bc_response_ent_block_priceT;

typedef struct
{
    char    isinCod[12];
    char    deactFromDat[DATE_LEN_BOSS];
    char    deactToDat[DATE_LEN_BOSS];
    char    deactComment[2];
    char    deactText[35];
}   bc_request_dea_pricing_blockT;

typedef struct
{
    char    isinCod[12];
    char    processingCod[1];
    char    tradMtchCod[3];
    char    tradMtchPrc[PRICE_BOSS];
    char    trdResTypCod[2];
    char    deactFromDat[DATE_LEN_BOSS];
    char    deactToDat[DATE_LEN_BOSS];
    char    deactComment[2];
    char    deactText[35];
}   bc_request_rea_pricing_blockT;

typedef struct
{
    char    maxNoPrc[3];
}   bc_response_pricing_block_noT;

typedef struct
{
    char    isinCod[12];
    char    errCod[9];
}   bc_response_pricing_blockT;

typedef struct
{
    char    tradMtchCod[3];
    char    tradMtchPrc[PRICE_BOSS];
    char    tradMtchPrcNo[5];
    char    trdResTypCod[2];
    char    ordrBkExeQty[16];
    char    enterTim[TIME_LEN_BOSS];
    char    refTim[TIME_LEN_BOSS];
    char    tradMtchPrcDat[DATE_LEN_BOSS];
}   bc_brd_ent_price_manT;

typedef struct
{
    char    counter[3];
}   bc_counterT;

typedef struct
{
    char    ctpyNo[4];
    char    buyCod;
    char    tradMtchPrc[PRICE_BOSS];
    char    changeQty[1+VOLUME_BOSS];
    char    tradBegDat[DATE_LEN_BOSS];
    char    tradContTim[TIME_LEN_BOSS];
    char    currExcRat[10];
    char    acrIntDay[4];
    char    acrIntDayCod[2];
    char    valueDatCod[2];
    char    valueDat[DATE_LEN_BOSS];
    char    repExchangeId[3];
    char    textTrad[35];
}   bc_brd_mod_humT;

typedef struct
{
    char exchangeQuoteVolRate[3];
    char exchangeQuoteVolMax[9];
}   bc_brd_exchange_quote_volume_infoT;

typedef struct
{
    char    inSeqNoRef[9];
}   bc_request_header_moT;

typedef struct
{
    char    occurrence[3];
}   bc_response_header_moT;

typedef struct
{
    char    buyCod;
    char    tradMtchQty[VOLUME_BOSS];
    char    origOrdrQty[VOLUME_BOSS];
    char    userOrdNum[16];
    char    exchangeOrdNum[13];
}   bc_request_enter_exchange_orderT;

typedef struct
{
    char    isinCod[12];
    char    tradMtchPrc[PRICE_BOSS];
    char    bkrNo[4];
    char    tradMtchQty[VOLUME_BOSS];
    char    tradBegDat[DATE_LEN_BOSS];
    char    tradContTim[TIME_LEN_BOSS];
    char    tradContTimFraction[4];
    char    tradContDat[DATE_LEN_BOSS];
    char    currExcRat[10];
    char    acrIntDay[4];
    char    acrIntDayCod[2];
    char    bonusRat[6];
    char    valueDatCod[2];
    char    valueDat[DATE_LEN_BOSS];
    char    trdTypXontro[2];
    char    tvTic[52];
    char    otcPostTradInd[3];
    char    shortSellCod[2];

    char    ctpyNoAsk[4];
    char    btradeNoAsk[13];
    char    matchFlagAsk[2];
    char    acctTypCodXontroAsk[2];
    char    iwOrdCodAsk[2];
    char    tradMtchPrcAsk[PRICE_BOSS];
    char    feeFlagAsk[2];
    char    feeAsk[10];
    char    repExchangeIdAsk[3];
    char    textTradAsk[35];
    char    onBehalfCtpyNoAsk[4];
    char    comCodAsk[2];
    char    comAmtAsk[12];
    char    comRateAsk[6];
    char    chargesAsk[12];

    char    ctpyNoBid[4];
    char    btradeNoBid[13];
    char    matchFlagBid[2];
    char    acctTypCodXontroBid[2];
    char    iwOrdCodBid[2];
    char    tradMtchPrcBid[PRICE_BOSS];
    char    feeFlagBid[2];
    char    feeBid[10];
    char    repExchangeIdBid[3];
    char    textTradBid[35];
    char    onBehalfCtpyNoBid[4];
    char    comCodBid[2];
    char    comAmtBid[12];
    char    comRateBid[6];
    char    chargesBid[12];
}   bc_request_enter_exchange_tradeT;

typedef struct
{
    char    tradMtchPrcNo[5];
    char    refTim[TIME_LEN_BOSS];
}   bc_brd_reset_priceT;

typedef struct
{
    char    isinCod[12];
    char    tradMtchCod[3];
    char    tradMtchPrc[PRICE_BOSS];
    char    tradMtchPrcNo[5];
    char    ordrBkExeQty[16];
    char    refTim[TIME_LEN_BOSS];
}   bc_request_reset_priceT;

typedef struct
{
    char    isinCod[12];
    char    tradMtchPrcNo[5];
    char    refTim[TIME_LEN_BOSS];
}   bc_request_reset_price_infoT;

typedef struct
{
    char    buyCod;
    char    ctpyNo[4];
    char    ordrExePrc[PRICE_BOSS];
    char    ordrExpDat[DATE_LEN_BOSS];
    char    ordrNo[13];
    char    ordrQty[VOLUME_BOSS];
    char    ordrResCod[3];
    char    trdResTypCod[2];
    char    userOrdNum[16];
}   bc_brd_reset_order_skmT;

typedef struct
{
    char    buyCod;
    char    bkrNo[4];
    char    ctpyNo[4];
    char    ordrExePrc[PRICE_BOSS];
    char    ordrExpDat[DATE_LEN_BOSS];
    char    ordrNo[13];
    char    ordrQty[VOLUME_BOSS];
    char    ordrResCod[3];
    char    trdResTypCod[2];
    char    userOrdNum[16];
}   bc_brd_reset_order_fmT;

typedef struct
{
    char    isinCod[12];
    char    instMnem[5];
    char    instShtNam[25];
    char    instAlphaCod[6];
    char    instSecCod[3];
    char    instSubSecCod[3];
    char    instStrtTradDat[DATE_LEN_BOSS];
    char    instStpTradDat[DATE_LEN_BOSS];
    char    instLastRedemptDat[DATE_LEN_BOSS];
    char    instXontroStrtTradDat[DATE_LEN_BOSS];
    char    instHistCod[3];
    char    instRondLotInc[3];
    char    instRondLotQty[VOLUME_BOSS];
    char    instRondLotMinQty[VOLUME_BOSS];
    char    emiCod[7];
    char    currTypCod[3];
    char    ordrResCodInd;
    char    untOfTrad[3];
    char    midAuctInd;
    char    auctRondLotInc[3];
    char    auctRondLotQty[VOLUME_BOSS];
    char    auctRondLotMinQty[VOLUME_BOSS];
    char    contAuctInd;
    char    contAuctRondLotInc[3];
    char    contAuctRondLotQty[VOLUME_BOSS];
    char    contAuctRondLotMinQty[VOLUME_BOSS];
    char    deactCod;
    char    tradMtchPrc[PRICE_BOSS];
    char    tradMtchCod[3];
    char    tickSizeXontro;
    char    cutoffTim[TIME_LEN_BOSS];
    char    fwdPricingDays[3];
    char    fwdPricingInd;
    char    strtSubscrptDat[DATE_LEN_BOSS];
    char    endSubscrptDat[DATE_LEN_BOSS];
    char    currTypCodDep[3];
    char    custodyTypCod[3];
}   bc_skontro_dataT;

typedef struct
{
    char    isinCod[12];
    char    deactCod;
    char    tradMtchPrc[PRICE_BOSS];
    char    tradMtchCod[3];
}   bc_skontro_isinT;

typedef struct
{
    char    acctTypCodXontro[2];
    char    bkrNo[4];
    char    buyCod;
    char    ctpyNo[4];
    char    isinCod[12];
    char    isinCodSrs[12];
    char    ordrExePrc[PRICE_BOSS];
    char    ordrExpDat[DATE_LEN_BOSS];
    char    ordrQty[VOLUME_BOSS];
    char    ordrResCod[3];
    char    ordrStopLim[LIMIT_BOSS];
    char    text[25];
    char    trdResTypCod[2];
    char    userOrdNum[16];
    char    fwdOrdrCod;
    char    netTypCodXontro;
    char    ticket[9];
    char    clientInd[1];
    char    clientCod[20];
    char    investmentInd[1];
    char    investmentCod[20];
    char    executionInd[1];
    char    executionCod[20];
    char    deaFlag[1];
    char    tradCapacityCod[1];
    char    optOutFlag[1];
    char    liquidityProvFlag[1];
}   bc_request_ent_ord_skmT;

typedef struct
{
    char    isinCod[12];
    char    ordrNo[13];
    char    ticket[9];
    char    ordrStatCod;
    char    clientInd[1];
    char    clientCod[20];
    char    investmentInd[1];
    char    investmentCod[20];
    char    executionInd[1];
    char    executionCod[20];
    char    killFlag[1];
}   bc_request_del_ord_skmT;

typedef struct
{
    char    isinCod[12];
    char    trdResTypCod[2];
}   bc_request_start_pricingT;

typedef struct
{
    char    isinCod[12];
    char    tradMtchCod[3];
    char    tradMtchPrc[PRICE_BOSS];
    char    trdResTypCod[2];
    char    ordrBkExeQty[16];
    char    currExcRat[10];
    char    postProcFlag;
    char    ticket[9];
}   bc_request_enter_priceT;

typedef struct
{
    char    isinCod[12];
    char    tradMtchCod[3];
    char    tradMtchPrc[PRICE_BOSS];
    char    trdResTypCod[2];
    char    ordrBkExeQty[16];
    char    currExcRat[10];
    char    ticket[9];
    char    checkExeQtyBid[VOLUME_BOSS];
    char    checkExeQtyAsk[VOLUME_BOSS];
    char    checkExePrcBid[PRICE_BOSS];
    char    checkExePrcAsk[PRICE_BOSS];
    char    possLockFlag;
    char    ctpyNoBid[4];
    char    ctpyNoAsk[4];
    char    tradMtchQty[VOLUME_BOSS];
    char    feeFlag[2];
    char    fee[10];
    char    tranFeeFlag[2];
    char    tranFee[10];
    char    allotCapQty[VOLUME_BOSS];
    char    allotType[2];    
}   bc_request_enter_price_plusT;

typedef struct
{
    char    checkExeQtyBid[VOLUME_BOSS];
    char    checkExeQtyAsk[VOLUME_BOSS];
    char    checkExePrcBid[PRICE_BOSS];
    char    checkExePrcAsk[PRICE_BOSS];
}   bc_response_enter_price_plusT;

typedef struct
{
    char    isinCod[12];
    char    ticket[9];
}   bc_request_cancel_pricingT;

typedef struct
{
    char    lockTim[TIME_LEN_BOSS];
    char    ticket[9];
    char    trdResTypCod[2];
    char    userNo[10];
}   bc_brd_lockT;

typedef struct
{
    char    isinCod[12];
    char    tradMtchPrcNo[5];
    char    ticket[9];
    char    buyCod;
    char    ctpyNo[4];
    char    tradMtchQty[VOLUME_BOSS];
    char    feeFlag[2];
    char    fee[10];
    char    tranFeeFlag[2];
    char    tranFee[10];
}   bc_request_add_posT;

typedef struct
{
    char    isinCod[12];
    char    ordrNo[13];
    char    tradMtchPrcNo[5];
    char    tradMtchQty[VOLUME_BOSS];
    char    ticket[9];
}   bc_request_modify_executionT;

typedef struct
{
    char    isinCod[12];
    char    tradMtchPrcNo[5];
    char    ticket[9];
    char    currExcRat[10];
}   bc_request_finish_pricingT;

typedef struct
{
    char    tradMtchPrcNo[5];
    char    buyCod;
    char    ctpyNo[4];
    char    tradMtchQty[VOLUME_BOSS];
    char    feeFlag[2];
    char    fee[10];
    char    tranFeeFlag[2];
    char    tranFee[10];
    char    inSeqNoRef[9];
}   bc_brd_add_posT;

typedef struct
{
    char    ordrNo[13];
    char    tradMtchPrcNo[5];
    char    tradMtchQty[VOLUME_BOSS];
    char    inSeqNoRef[9];
}   bc_brd_modify_executionT;

typedef struct
{
    char    isinCod[12];
    char    deactFromDat[DATE_LEN_BOSS];
    char    deactToDat[DATE_LEN_BOSS];
    char    deactComment[2];
    char    deactText[35];
}   bc_request_dea_pricingT;

typedef struct
{
    char    isinCod[12];
    char    deactText[35];
}   bc_request_rea_pricingT;

typedef struct
{
    char    nrCod[4];
    char    isinCod[12];
    char    isinCodNew[12];
    char    ordrExePrcMod[11];
    char    nrDat[DATE_LEN_BOSS];
}   bc_request_sp_rightT;

typedef struct
{
    char    tradNo[13];
    char    isinCod[12];
    char    buyCod;
    char    ctpyNo[4];
}   bc_request_can_tradeT;

/*######################################################################
#
# XONTRO Enter Mass Quote
#
########################################################################*/

typedef struct
{
    char    quoteSeqNo[9];
    char    isinCod[12];
    char    ordrExePrcAsk[PRICE_BOSS];
    char    ordrQtyAsk[VOLUME_BOSS];
    char    ordrExePrcBid[PRICE_BOSS];
    char    ordrQtyBid[VOLUME_BOSS];
    char    confirmTim[TIME_LEN_BOSS];
    char    quoteTimeStamp[TIME_STAMP_BOSS];
}   bc_request_ent_mass_quoteT;

typedef struct
{
    char    quoteReturnCod[1];
}   bc_response_ent_mass_quoteT;


#endif    /* #ifndef _BC_BCLAYOUTS_QSAM_H_ */
